@@ -3,7 +3,7 @@ package fxtest
 import (
 	"os"
 
-	logging "github.com/ipfs/go-log"
+	logging "github.com/ipfs/go-log/v2"
 	"github.com/ipfs/kubo/core"
 	"github.com/ipfs/kubo/plugin"
 	"go.uber.org/fx"
